@@ -530,6 +530,8 @@ class _Trochoid(ABC):
                 theta_step = .1
             thetas = np.arange(theta_start, theta_stop, theta_step)
         thetas = np.array(thetas)
+        if len(thetas) == 0:
+            raise ValueError("An empty list of thetas was passed in as argument.")
         return thetas
 
     def _init_screen(
@@ -547,7 +549,15 @@ class _Trochoid(ABC):
             self, color: str, circle_color: str, full_path_color: str,
             hide_turtle: bool, width: Number
         ) -> Tuple["turtle.Turtle", "turtle.Turtle", "turtle.Turtle", "turtle.Turtle"]:
-        """Return a shape turtle, rolling circle turtle, and fixed circle turtle"""
+        """
+        Initialize four turtle objects with the specified color, width, and visibility.
+
+        The returned tuple contains four turtles:
+        - shape_turtle: the main turtle shape.
+        - rolling_circle_turtle: a turtle used for drawing a rolling circle.
+        - fixed_circle_turtle: a turtle used for drawing a fixed circle.
+        - pre_draw_turtle: a turtle used for drawing the full path.
+        """
 
         # Instantiate turtle
         shape_turtle = turtle.Turtle()
@@ -674,12 +684,9 @@ class _Trochoid(ABC):
     def __repr__(self) -> str:
         """Return formatted string with useful information about the current object"""
         # pylint: disable=line-too-long
-        if len(self.thetas) == 1:
-            thetas_str = f"[{self.thetas[0]}]"
-        elif len(self.thetas) == 2:
-            thetas_str = f"[{self.thetas[0]}, {self.thetas[1]}]"
-        elif len(self.thetas) == 3:
-            thetas_str = f"[{self.thetas[0]}, {self.thetas[1]}, {self.thetas[2]}]"
+        if len(self.thetas) < 4:
+            thetas_str_list = map(str, self.thetas)
+            thetas_str = ', '.join(thetas_str_list)
         else:
-            thetas_str = f"[{self.thetas[0]}, {self.thetas[1]}, ... {self.thetas[-1]}]"
-        return(f"{self.__class__.__name__}(R={self.R}, r={self.r}, d={self.d}, thetas={thetas_str}, origin=({self.origin[0]},{self.origin[1]}))")
+            thetas_str = '{0}, {1}, ... {2}'.format(min(self.thetas), "{:.1f}".format(self.thetas[1]-self.thetas[0]), max(self.thetas))
+        return(f"{self.__class__.__name__}(R={self.R}, r={self.r}, d={self.d}, thetas=[{thetas_str}], origin=({self.origin[0]},{self.origin[1]}))")
